'use strict';

// Do this as the first thing so that any code reading it knows the right env.
var _interopRequireDefault = require("@babel/runtime/helpers/interopRequireDefault");
var _defineProperty2 = _interopRequireDefault(require("@babel/runtime/helpers/defineProperty"));
function ownKeys(e, r) { var t = Object.keys(e); if (Object.getOwnPropertySymbols) { var o = Object.getOwnPropertySymbols(e); r && (o = o.filter(function (r) { return Object.getOwnPropertyDescriptor(e, r).enumerable; })), t.push.apply(t, o); } return t; }
function _objectSpread(e) { for (var r = 1; r < arguments.length; r++) { var t = null != arguments[r] ? arguments[r] : {}; r % 2 ? ownKeys(Object(t), !0).forEach(function (r) { (0, _defineProperty2["default"])(e, r, t[r]); }) : Object.getOwnPropertyDescriptors ? Object.defineProperties(e, Object.getOwnPropertyDescriptors(t)) : ownKeys(Object(t)).forEach(function (r) { Object.defineProperty(e, r, Object.getOwnPropertyDescriptor(t, r)); }); } return e; }
process.env.BABEL_ENV = 'development';
process.env.NODE_ENV = 'development';

// Makes the script crash on unhandled rejections instead of silently
// ignoring them. In the future, promise rejections that are not handled will
// terminate the Node.js process with a non-zero exit code.
process.on('unhandledRejection', function (err) {
  throw err;
});
var writeInformation = require("./predev/writeInformation.js");
writeInformation();

// Ensure environment variables are read.
require('../config/env');
var fs = require('fs');
var chalk = require('react-dev-utils/chalk');
var webpack = require('webpack');
var WebpackDevServer = require('webpack-dev-server');
var clearConsole = require('react-dev-utils/clearConsole');
var checkRequiredFiles = require('react-dev-utils/checkRequiredFiles');
var _require = require('react-dev-utils/WebpackDevServerUtils'),
  choosePort = _require.choosePort,
  createCompiler = _require.createCompiler,
  prepareProxy = _require.prepareProxy,
  prepareUrls = _require.prepareUrls;
var openBrowser = require('react-dev-utils/openBrowser');
var semver = require('semver');
var paths = require('../config/paths');
var configFactory = require('../config/webpack.config');
var createDevServerConfig = require('../config/webpackDevServer.config');
var getClientEnvironment = require('../config/env');
var resolveUsablePort = require("resolve-usable-port");
var react = require(require.resolve('react', {
  paths: [paths.appPath]
}));
var env = getClientEnvironment(paths.publicUrlOrPath.slice(0, -1));
var useYarn = fs.existsSync(paths.yarnLockFile);
var isInteractive = process.stdout.isTTY;

// Warn and crash if required files are missing
if (!checkRequiredFiles([paths.appHtml, paths.appIndexJs])) {
  process.exit(1);
}

// Tools like Cloud9 rely on this.
var DEFAULT_PORT = parseInt(process.env.PORT, 10) || 3000;
var HOST = process.env.HOST || '0.0.0.0';
if (process.env.HOST) {
  console.log(chalk.cyan("Attempting to bind to HOST environment variable: ".concat(chalk.yellow(chalk.bold(process.env.HOST)))));
  console.log("If this was unintentional, check that you haven't mistakenly set it in your shell.");
  console.log("Learn more here: ".concat(chalk.yellow('https://cra.link/advanced-config')));
  console.log();
}

// We require that you explicitly set browsers and do not fall back to
// browserslist defaults.
var _require2 = require('react-dev-utils/browsersHelper'),
  checkBrowsers = _require2.checkBrowsers;
checkBrowsers(paths.appPath, isInteractive).then(function () {
  return resolveUsablePort(3000).then(function (port) {
    return choosePort(HOST, port);
  });
}).then(function (port) {
  if (port == null) {
    // We have not found a port.
    return;
  }
  var config = configFactory('development');
  var protocol = process.env.HTTPS === 'true' ? 'https' : 'http';
  var appName = require(paths.appPackageJson).name;
  var useTypeScript = fs.existsSync(paths.appTsConfig);
  var urls = prepareUrls(protocol, HOST, port, paths.publicUrlOrPath.slice(0, -1));
  // Create a webpack compiler that is configured with custom messages.
  var compiler = createCompiler({
    appName: appName,
    config: config,
    urls: urls,
    useYarn: useYarn,
    useTypeScript: useTypeScript,
    webpack: webpack
  });
  // Load proxy config
  var proxySetting = require(paths.appPackageJson).proxy;
  var proxyConfig = prepareProxy(proxySetting);
  // Serve webpack assets generated by the compiler over a web server.
  var serverConfig = _objectSpread(_objectSpread({}, createDevServerConfig(proxyConfig, urls.lanUrlForConfig)), {}, {
    host: HOST,
    port: port
  });
  var devServer = new WebpackDevServer(serverConfig, compiler);
  // Launch WebpackDevServer.
  devServer.startCallback(function () {
    if (isInteractive) {
      clearConsole();
    }
    if (env.raw.FAST_REFRESH && semver.lt(react.version, '16.10.0')) {
      console.log(chalk.yellow("Fast Refresh requires React 16.10 or higher. You are using React ".concat(react.version, ".")));
    }
    console.log(chalk.cyan('Starting the development server...\n'));
    openBrowser(urls.localUrlForBrowser);
  });
  ['SIGINT', 'SIGTERM'].forEach(function (sig) {
    process.on(sig, function () {
      devServer.close();
      process.exit();
    });
  });
  if (process.env.CI !== 'true') {
    // Gracefully exit when stdin ends
    process.stdin.on('end', function () {
      devServer.close();
      process.exit();
    });
  }
})["catch"](function (err) {
  if (err && err.message) {
    console.log(err.message);
  }
  process.exit(1);
});