const path = require("path")
const isEnvProduction = process.env.NODE_ENV === "production"
const debuggerMode = !(process.env.VUE_APP_NEEDSOURCEMAP === "false")
const onlineDevelopmentMode = process.env.VUE_APP_ONLINE_DEVELOPMENT_MODE === "true"
const CopyWebpackPlugin = require("copy-webpack-plugin");
const cwd = process.cwd();
const webpack = require("webpack");
const myProxy = require(cwd + '/proxy')

module.exports = {
  terser: {
    terserOptions: {
      compress: {
        drop_debugger: isEnvProduction && !debuggerMode,
        pure_funcs: (isEnvProduction && !debuggerMode) ? ["console.log", "console.error", "console.warning"] : []
      },
      output: {
        ascii_only: isEnvProduction && !debuggerMode
      }
    }
  },
  configureWebpack: config => {
    const configs  ={
      plugins: [
        new CopyWebpackPlugin({
          patterns: [{
            from: path.resolve(__dirname + "/../assets"),
            to: './assets/'
          }, {
            from: path.resolve(cwd + "/src/assets"),
            to: './assets/'
          }]
        }),
        new webpack.DefinePlugin({
          'process.env.PLUGIN_TYPE': JSON.stringify(process.env.PLUGIN_TYPE),
          'process.env.TEMPLATE_TYPE': JSON.stringify(process.env.TEMPLATE_TYPE),
          'process.env.VUE_APP_ONLINE_DEVELOPMENT_MODE': JSON.stringify(process.env.VUE_APP_ONLINE_DEVELOPMENT_MODE),
        }),
      ]}
    if (isEnvProduction) {
      configs.devtool = debuggerMode ? "eval-source-map" : "source-map"
    }
    return configs
  },
  publicPath: "auto",
  devServer: {
    open: true,
    proxy: myProxy
  },
  chainWebpack: (config) => {
    config
        .plugin('html')
        .tap(args => {
          args[0].template = cwd + '/index.html'
          return args
        })
    //拼接output.prod.js
    process.env.VUE_APP_PRODCONF && console.log("const Config = ")
    config.when(onlineDevelopmentMode, (config) => {
      config.plugins.delete("hmr")
    })
    config.optimization.splitChunks(false)
    config.plugins.delete("extract-css");
    config.module
        .rule('adapter-js')
        .test(/\.js$/)
        .use('babel-loader')
        .loader('babel-loader');
    ["postcss", "scss", "css", "sass", "less", "stylus"].forEach(
      (element) => {
        ["vue-modules", "vue", "normal-modules", "normal"].forEach((m) => {
          config.module
            .rule(element)
            .oneOf(m)
            .uses.delete("extract-css-loader")
            .end()
            .use("vue-style-loader")
            .loader("vue-style-loader")
            .options({
              sourceMap: false,
              shadowMode: false
            })
            .before("css-loader")
        })
      }
    )
    config.resolve.alias
      .set("@", path.resolve(cwd + "/src"))
        .set("configJson", path.resolve(cwd+"/config.json"))
        .set("information", path.resolve(__dirname+"/scripts/information.json"))
    config.module
      .rule("images")
      .parser({dataUrlCondition: {maxSize: 1000}})
      .set("generator", {filename: "media/[name].[hash:8][ext]"})
    config.module
      .rule("fonts")
      .parser({dataUrlCondition: {maxSize: 1000}})
      .set("generator", {filename: "media/[name].[hash:8][ext]"})
    config.module
      .rule("svg")
      .set("generator", {filename: "media/[name].[hash:8][ext]"})
  }
}
